pub struct ContainerDebug {
pub error_ref: u32,
pub latency_ms: i64,
pub was_buffered: bool,
pub buffer_ms: i64,
pub buffer_eviction_reason_ref: u32,
}Expand description
ContainerDebug holds debug information about the container tags resolution process.
Fields
error_ref: u32errorRef specifies the string table ref of any error that occurred during container tag resolution.
latency_ms: i64latencyMs specifies the latency in milliseconds of the container tag resolution.
was_buffered: boolwasBuffered specifies whether the payload was buffered while waiting for container tags.
buffer_ms: i64bufferMs specifies how long the payload was buffered in milliseconds.
buffer_eviction_reason_ref: u32bufferEvictionReasonRef specifies the string table ref of why the payload was evicted from the buffer.