pub struct AgentPayload {
pub host_name: String,
pub env: String,
pub tracer_payloads: Vec<TracerPayload>,
pub tags: HashMap<String, String>,
pub agent_version: String,
pub target_tps: f64,
pub error_tps: f64,
pub rare_sampler_enabled: bool,
pub idx_tracer_payloads: Vec<TracerPayload>,
}Expand description
AgentPayload represents payload the agent sends to the intake.
Fields
host_name: StringhostName specifies hostname of where the agent is running.
env: Stringenv specifies env set in agent configuration.
tracer_payloads: Vec<TracerPayload>tracerPayloads specifies list of the payloads received from tracers.
tags specifies tags common in all tracerPayloads.
agent_version: StringagentVersion specifies version of the agent.
target_tps: f64targetTPS holds TargetTPS value in AgentConfig.
error_tps: f64errorTPS holds ErrorTPS value in AgentConfig.
rare_sampler_enabled: boolrareSamplerEnabled holds RareSamplerEnabled value in AgentConfig
idx_tracer_payloads: Vec<TracerPayload>idxTracerPayloads specifies list of the payloads received from tracers. @gotags: msg:“-”