pub struct AttributeAnyValue {
pub type: i32,
pub string_value: String,
pub bool_value: bool,
pub int_value: i64,
pub double_value: f64,
pub array_value: Option<AttributeArray>,
}Expand description
AttributeAnyValue is used to represent any type of attribute value. AttributeAnyValue may contain a primitive value such as a string or integer or it may contain an arbitrary nested object containing arrays, key-value lists and primitives.
Fields
type: i32We implement a union manually here because Go’s MessagePack generator does not support
Protobuf oneof unions: https://github.com/tinylib/msgp/issues/184
Despite this, the format represented here is binary compatible with oneof, if we choose
to migrate to that in the future.
@gotags: json:“type” msg:“type”
string_value: String@gotags: json:“string_value” msg:“string_value”
bool_value: bool@gotags: json:“bool_value” msg:“bool_value”
int_value: i64@gotags: json:“int_value” msg:“int_value”
double_value: f64@gotags: json:“double_value” msg:“double_value”
array_value: Option<AttributeArray>@gotags: json:“array_value” msg:“array_value”
Implementations
Sourceimpl AttributeAnyValue
impl AttributeAnyValue
Sourcepub fn type(&self) -> AttributeAnyValueType
pub fn type(&self) -> AttributeAnyValueType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: AttributeAnyValueType)
pub fn set_type(&mut self, value: AttributeAnyValueType)
Sets type to the provided enum value.