pub struct AttributeArrayValue {
pub type: i32,
pub string_value: String,
pub bool_value: bool,
pub int_value: i64,
pub double_value: f64,
}Expand description
An element in the homogeneous AttributeArray. Compared to AttributeAnyValue, it only supports scalar values.
Fields
type: i32We implement a union manually here because Go’s MessagePack generator does not support
Protobuf oneof unions: https://github.com/tinylib/msgp/issues/184
Despite this, the format represented here is binary compatible with oneof, if we choose
to migrate to that in the future.
@gotags: json:“type” msg:“type”
string_value: String@gotags: json:“string_value” msg:“string_value”
bool_value: bool@gotags: json:“bool_value” msg:“bool_value”
int_value: i64@gotags: json:“int_value” msg:“int_value”
double_value: f64@gotags: json:“double_value” msg:“double_value”
Implementations
Sourceimpl AttributeArrayValue
impl AttributeArrayValue
Sourcepub fn type(&self) -> AttributeArrayValueType
pub fn type(&self) -> AttributeArrayValueType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: AttributeArrayValueType)
pub fn set_type(&mut self, value: AttributeArrayValueType)
Sets type to the provided enum value.