pub struct ClientGroupedStats {Show 21 fields
pub service: String,
pub name: String,
pub resource: String,
pub http_status_code: u32,
pub type: String,
pub db_type: String,
pub hits: u64,
pub errors: u64,
pub duration: u64,
pub ok_summary: Vec<u8>,
pub error_summary: Vec<u8>,
pub synthetics: bool,
pub top_level_hits: u64,
pub span_kind: String,
pub peer_tags: Vec<String>,
pub is_trace_root: i32,
pub grpc_status_code: String,
pub http_method: String,
pub http_endpoint: String,
pub service_source: String,
pub span_derived_primary_tags: Vec<String>,
}Expand description
ClientGroupedStats aggregate stats on spans grouped by service, name, resource, status_code, type
Fields
service: Stringname: Stringresource: Stringhttp_status_code: u32type: Stringdb_type: Stringdb_type might be used in the future to help in the obfuscation step
hits: u64count of all spans aggregated in the groupedstats
errors: u64count of error spans aggregated in the groupedstats
duration: u64total duration in nanoseconds of spans aggregated in the bucket
ok_summary: Vec<u8>ddsketch summary of ok spans latencies encoded in protobuf
error_summary: Vec<u8>ddsketch summary of error spans latencies encoded in protobuf
synthetics: boolset to true on spans generated by synthetics traffic
top_level_hits: u64count of top level spans aggregated in the groupedstats
span_kind: Stringvalue of the span.kind tag on the span
peer_tags are supplementary tags that further describe a peer entity
E.g., grpc.target to describe the name of a gRPC peer, or db.hostname to describe the name of peer DB
is_trace_root: i32this field’s value is equal to span’s ParentID == 0.
grpc_status_code: Stringhttp_method: StringHTTP method of the request
http_endpoint: StringHttp route or quantized/simplified URL path
service_source: String@inject_tag: msg:“srv_src”
used to identify service override origin
span_derived_primary_tags are user-configured tags that are extracted from spans and used for stats aggregation
E.g., aws.s3.bucket, http.url, or any custom tag
Implementations
Sourceimpl ClientGroupedStats
impl ClientGroupedStats
Sourcepub fn is_trace_root(&self) -> Trilean
pub fn is_trace_root(&self) -> Trilean
Returns the enum value of is_trace_root, or the default if the field is set to an invalid enum value.
Sourcepub fn set_is_trace_root(&mut self, value: Trilean)
pub fn set_is_trace_root(&mut self, value: Trilean)
Sets is_trace_root to the provided enum value.