ClientStatsBucket

Struct ClientStatsBucket 

pub struct ClientStatsBucket {
    pub start: u64,
    pub duration: u64,
    pub stats: Vec<ClientGroupedStats>,
    pub agent_time_shift: i64,
}
ClientStatsBucket is a time bucket containing aggregated stats.

Fields

start: u64

bucket start in nanoseconds

duration: u64

bucket duration in nanoseconds

stats: Vec<ClientGroupedStats>

@gotags: json:“stats,omitempty” msg:“Stats,omitempty”

agent_time_shift: i64

AgentTimeShift is the shift applied by the agent stats aggregator on bucket start when the received bucket start is outside of the agent aggregation window