pub struct ClientStatsPayload {Show 16 fields
pub hostname: String,
pub env: String,
pub version: String,
pub stats: Vec<ClientStatsBucket>,
pub lang: String,
pub tracer_version: String,
pub runtime_id: String,
pub sequence: u64,
pub agent_aggregation: String,
pub service: String,
pub container_id: String,
pub tags: Vec<String>,
pub git_commit_sha: String,
pub image_tag: String,
pub process_tags_hash: u64,
pub process_tags: String,
}Expand description
ClientStatsPayload is the first layer of span stats aggregation. It is also the payload sent by tracers to the agent when stats in tracer are enabled.
Fields
hostname: StringHostname is the tracer hostname. It’s extracted from spans with “_dd.hostname” meta or set by tracer stats payload when hostname reporting is enabled.
env: Stringenv tag set on spans or in the tracers, used for aggregation
version: Stringversion tag set on spans or in the tracers, used for aggregation
stats: Vec<ClientStatsBucket>@gotags: json:“stats,omitempty” msg:“Stats,omitempty”
lang: Stringinformative field not used for aggregation
tracer_version: Stringinformative field not used for aggregation
runtime_id: Stringused on stats payloads sent by the tracer to identify uniquely a message
sequence: u64used on stats payloads sent by the tracer to identify uniquely a message
agent_aggregation: StringAgentAggregation is set by the agent on tracer payloads modified by the agent aggregation layer characterizes counts only and distributions only payloads
service: StringService is the main service of the tracer. It is part of unified tagging: https://docs.datadoghq.com/getting_started/tagging/unified_service_tagging
container_id: StringContainerID specifies the origin container ID. It is meant to be populated by the client and may be enhanced by the agent to ensure it is unique.
Tags specifies a set of tags obtained from the orchestrator (where applicable) using the specified containerID. This field should be left empty by the client. It only applies to some specific environment.
git_commit_sha: StringThe git commit SHA is obtained from a trace, where it may be set through a tracer <-> source code integration.
image_tag: StringThe image tag is obtained from a container’s set of tags.
The process tags hash is used as a key for agent stats agregation.
The process tags contains a list of tags that are specific to the process.