Span

Struct Span 

pub struct Span {
Show 15 fields pub service: String, pub name: String, pub resource: String, pub trace_id: u64, pub span_id: u64, pub parent_id: u64, pub start: i64, pub duration: i64, pub error: i32, pub meta: HashMap<String, String>, pub metrics: HashMap<String, f64>, pub type: String, pub meta_struct: HashMap<String, Vec<u8>>, pub span_links: Vec<SpanLink>, pub span_events: Vec<SpanEvent>,
}

Fields

service: String

service is the name of the service with which this span is associated. @gotags: json:“service” msg:“service”

name: String

name is the operation name of this span. @gotags: json:“name” msg:“name”

resource: String

resource is the resource name of this span, also sometimes called the endpoint (for web spans). @gotags: json:“resource” msg:“resource”

trace_id: u64

traceID is the ID of the trace to which this span belongs. @gotags: json:“trace_id” msg:“trace_id”

span_id: u64

spanID is the ID of this span. @gotags: json:“span_id” msg:“span_id”

parent_id: u64

parentID is the ID of this span’s parent, or zero if this span has no parent. @gotags: json:“parent_id” msg:“parent_id”

start: i64

start is the number of nanoseconds between the Unix epoch and the beginning of this span. @gotags: json:“start” msg:“start”

duration: i64

duration is the time length of this span in nanoseconds. @gotags: json:“duration” msg:“duration”

error: i32

error is 1 if there is an error associated with this span, or 0 if there is not. @gotags: json:“error” msg:“error”

meta: HashMap<String, String>

meta is a mapping from tag name to tag value for string-valued tags. @gotags: json:“meta,omitempty” msg:“meta,omitempty”

metrics: HashMap<String, f64>

metrics is a mapping from tag name to tag value for numeric-valued tags. @gotags: json:“metrics,omitempty” msg:“metrics,omitempty”

type: String

type is the type of the service with which this span is associated. Example values: web, db, lambda. @gotags: json:“type” msg:“type”

meta_struct: HashMap<String, Vec<u8>>

meta_struct is a registry of structured “other” data used by, e.g., AppSec. @gotags: json:“meta_struct,omitempty” msg:“meta_struct,omitempty”

span_links: Vec<SpanLink>

span_links represents a collection of links, where each link defines a causal relationship between two spans. @gotags: json:“span_links,omitempty” msg:“span_links,omitempty”

span_events: Vec<SpanEvent>

spanEvents represent an event at an instant in time related to this span, but not necessarily during the span. @gotags: json:“span_events,omitempty” msg:“span_events,omitempty”