pub struct SpanEvent {
pub time_unix_nano: u64,
pub name: String,
pub attributes: HashMap<String, AttributeAnyValue>,
}Fields
time_unix_nano: u64@gotags: json:“time_unix_nano” msg:“time_unix_nano”
time is the number of nanoseconds between the Unix epoch and this event.
name: String@gotags: json:“name” msg:“name”
name is this event’s name.
attributes: HashMap<String, AttributeAnyValue>attributes is a mapping from attribute key string to any value. The order of attributes should be preserved in the key/value map. The supported values match the OpenTelemetry attributes specification: https://github.com/open-telemetry/opentelemetry-proto/blob/a8f08fc49d60538f97ffabcc7feac92f832976dd/opentelemetry/proto/common/v1/common.proto @gotags: json:“attributes” msg:“attributes”