pub struct StatsPayload {
pub agent_hostname: String,
pub agent_env: String,
pub stats: Vec<ClientStatsPayload>,
pub agent_version: String,
pub client_computed: bool,
pub split_payload: bool,
}Expand description
StatsPayload is the payload used to send stats from the agent to the backend.
Fields
agent_hostname: Stringagent_env: Stringstats: Vec<ClientStatsPayload>@gotags: json:“stats,omitempty” msg:“Stats,omitempty”
agent_version: Stringclient_computed: boolsplit_payload: boolsplitPayload indicates if the payload is actually one of several payloads split out from a larger payload. This field can be used in the backend to signal if re-aggregation is necessary.